(* =============================================================================

   Ein Plugin zum Erstellen und Einfgen von GUIDs

   Original fr Phase 5 von Mathias Simmack,
   fr AlphaCode umgeschrieben von David Fekete

   (c) 2005 Mathias Simmack, David Fekete
   Alle Rechte vorbehalten.

============================================================================= *)

library createuuid;
uses
  AlphaCodePluginInterface_TLB,
  Windows,
  ComObj;

{$E dll}

type
  TGUIDPlugin = class(TInterfacedObject, IPlugin)
  public
    function GetName: WideString; stdcall;
    function GetAuthor: WideString; stdcall;
    function GetComment: WideString; stdcall;
    function EventHandler(EventNotification: TEventNotification
      ): TEventAction; stdcall;
end;

type
  TOnClick = procedure(const Sender: IUnknown) of object;
  TOnClickHandler = class(TInterfacedObject, INotifyEvent)
  private
    FOnClick: TOnClick;
  public
    property OnClickProc: TOnClick read FOnClick write FOnClick;
    procedure OnClick(const Sender: IUnknown); stdcall;
end;

type
  TMenuItemHandler = class(TInterfacedObject)
  private
    FApplication: IApplication;
  public
     constructor Create(const Application: IApplication);
     procedure MenuItemHandler(const Sender: IUnknown);
end;

{ TGUIDPlugin }

function TGUIDPlugin.EventHandler(
  EventNotification: TEventNotification): TEventAction;
begin
  Result := evnContinue;
end;

function TGUIDPlugin.GetAuthor: WideString;
begin
  Result := 'Mathias Simmack';
end;

function TGUIDPlugin.GetComment: WideString;
begin
  Result := 'Erstellt eine ClassID und fgt Sie in den Text ein.';
end;

function TGUIDPlugin.GetName: WideString;
begin
  Result := 'Createuuid';
end;

{ TOnClickHandler }

procedure TOnClickHandler.OnClick(const Sender: IInterface);
begin
  if (@FOnClick <> nil) then
    FOnClick(Sender);
end;

{ TMenuItemHandler }

constructor TMenuItemHandler.Create(const Application: IApplication);
begin
  FApplication := Application;
end;

procedure TMenuItemHandler.MenuItemHandler(const Sender: IInterface);
var
  InsertText: string;
begin
  if FApplication.CanEditDocuments then
  begin
    InsertText := CreateClassId;
    Delete(InsertText, 1, 1);
    Delete(InsertText, Length(InsertText), 1);
    FApplication.GetActiveDocument.GetEditor.InsertText(InsertText, True);
  end;
end;

{ Load Plugin }

function LoadPlugIn(const Parent: IApplication; var Plugin: IPlugin): WordBool;
  stdcall;
var
  Handler : TMenuItemHandler;
  OnClick : TOnClickHandler;
  MenuItem: IMenuItem;
begin
  try
    Plugin := TGUIDPlugin.Create;
    Result := True;
  except
    Result := False;
  end;
  Handler := TMenuItemHandler.Create(Parent);
  OnClick := TOnClickHandler.Create;
  OnClick.OnClickProc := Handler.MenuItemHandler;
  MenuItem := Parent.GetMainMenu.GetMenuItems.FindItem('MenuPaste');
  // TextToShortCut('Strg+Umsch+G') = 24647
  if MenuItem <> nil then
    MenuItem.InsertMenuItem(MenuItem.GetMenuItems.GetCount-1,
    'GUID einfgen',
    'Fgt eine Windows Class ID in das aktuelle Dokument ein.',
    'mmInsert_GUID', 24647, 0, -1, OnClick);
end;


exports
  LoadPlugIn name 'LoadPlugIn';

end.
